==> ejc-probid-api-3.0.0-20220719.022110-22-sources.jar: com/ejianc/business/win/vo/WinVO.java <==
package com.ejianc.business.win.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 中标登记实体
 *
 * @author generator
 */
public class WinVO extends BaseVO {
	private static final long serialVersionUID = -3085743816275732574L;

	private Long employeeId; // 填报人（经办人）id
	private String employeeName; // 填报人（经办人）名称
	private Date commitDate; // 提交日期
	private String commitUserName; // 提交人名称
	private String commitUserCode; // 提交人账号
	private Date effectiveDate; // 生效日期
	private String billCode; // 单据编码
	private String billName; // 单据名称
	private String billType; // 单据类型
	private Integer billState; // 单据状态
	private String billStateName; // 单据状态名称
	private Long projectId; // 项目id
	private String projectCode; // 项目编码
	private String projectName; // 项目名称
	private String constructionUnit; // 建设单位
	private Date registrationDeadline; // 报名截止日期
	private Date bidOpenDate; // 开标日期
	private Long bidUnitId; // 投标单位id
	private String bidUnitCode; // 投标单位编码
	private String bidUnitName; // 投标单位名称
	private String bidWinFlag; // 是否中标 0-否，1-是
	private String bidWinCompanyName; // 中标单位
	private BigDecimal bidWinMny; // 中标金额
	private Date handleDate; // 填报日期


	public Long getEmployeeId() {
		return employeeId;
	}

	public void setEmployeeId(Long employeeId) {
		this.employeeId = employeeId;
	}

	public String getEmployeeName() {
		return employeeName;
	}

	public void setEmployeeName(String employeeName) {
		this.employeeName = employeeName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public Date getEffectiveDate() {
		return effectiveDate;
	}

	public void setEffectiveDate(Date effectiveDate) {
		this.effectiveDate = effectiveDate;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public String getBillName() {
		return billName;
	}

	public void setBillName(String billName) {
		this.billName = billName;
	}

	public String getBillType() {
		return billType;
	}

	public void setBillType(String billType) {
		this.billType = billType;
	}

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public String getBillStateName() {
		return billStateName;
	}

	public void setBillStateName(String billStateName) {
		this.billStateName = billStateName;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectCode() {
		return projectCode;
	}

	public void setProjectCode(String projectCode) {
		this.projectCode = projectCode;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getConstructionUnit() {
		return constructionUnit;
	}

	public void setConstructionUnit(String constructionUnit) {
		this.constructionUnit = constructionUnit;
	}

	public Date getRegistrationDeadline() {
		return registrationDeadline;
	}

	public void setRegistrationDeadline(Date registrationDeadline) {
		this.registrationDeadline = registrationDeadline;
	}

	public Date getBidOpenDate() {
		return bidOpenDate;
	}

	public void setBidOpenDate(Date bidOpenDate) {
		this.bidOpenDate = bidOpenDate;
	}

	public Long getBidUnitId() {
		return bidUnitId;
	}

	public void setBidUnitId(Long bidUnitId) {
		this.bidUnitId = bidUnitId;
	}

	public String getBidUnitCode() {
		return bidUnitCode;
	}

	public void setBidUnitCode(String bidUnitCode) {
		this.bidUnitCode = bidUnitCode;
	}

	public String getBidUnitName() {
		return bidUnitName;
	}

	public void setBidUnitName(String bidUnitName) {
		this.bidUnitName = bidUnitName;
	}

	public String getBidWinFlag() {
		return bidWinFlag;
	}

	public void setBidWinFlag(String bidWinFlag) {
		this.bidWinFlag = bidWinFlag;
	}

	public String getBidWinCompanyName() {
		return bidWinCompanyName;
	}

	public void setBidWinCompanyName(String bidWinCompanyName) {
		this.bidWinCompanyName = bidWinCompanyName;
	}

	public BigDecimal getBidWinMny() {
		return bidWinMny;
	}

	public void setBidWinMny(BigDecimal bidWinMny) {
		this.bidWinMny = bidWinMny;
	}

	public Date getHandleDate() {
		return handleDate;
	}

	public void setHandleDate(Date handleDate) {
		this.handleDate = handleDate;
	}

}

==> ejc-probid-api-3.0.0-20220726.083507-57-sources.jar: com/ejianc/business/win/vo/WinVO.java <==
package com.ejianc.business.win.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 中标登记实体
 *
 * @author generator
 */
public class WinVO extends BaseVO {
	private static final long serialVersionUID = -3085743816275732574L;

	private Long employeeId; // 填报人（经办人）id
	private String employeeName; // 填报人（经办人）名称
	private Date commitDate; // 提交日期
	private String commitUserName; // 提交人名称
	private String commitUserCode; // 提交人账号
	private Date effectiveDate; // 生效日期
	private String billCode; // 单据编码
	private String billName; // 单据名称
	private String billType; // 单据类型
	private Integer billState; // 单据状态
	private String billStateName; // 单据状态名称
	private Long projectId; // 项目id
	private String projectCode; // 项目编码
	private String projectName; // 项目名称
	private String constructionUnit; // 建设单位
	@JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date registrationDeadline; // 报名截止日期
	@JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date bidOpenDate; // 开标日期
	private Long bidUnitId; // 投标单位id
	private String bidUnitCode; // 投标单位编码
	private String bidUnitName; // 投标单位名称
	private String bidWinFlag; // 是否中标 0-否，1-是
	private String bidWinFlagName; // 是否中标名称
	private String bidWinCompanyName; // 中标单位
	private BigDecimal bidWinMny; // 中标金额
	@JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date handleDate; // 填报日期


	public Long getEmployeeId() {
		return employeeId;
	}

	@ReferDeserialTransfer
	public void setEmployeeId(Long employeeId) {
		this.employeeId = employeeId;
	}

	public String getEmployeeName() {
		return employeeName;
	}

	public void setEmployeeName(String employeeName) {
		this.employeeName = employeeName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public Date getEffectiveDate() {
		return effectiveDate;
	}

	public void setEffectiveDate(Date effectiveDate) {
		this.effectiveDate = effectiveDate;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public String getBillName() {
		return billName;
	}

	public void setBillName(String billName) {
		this.billName = billName;
	}

	public String getBillType() {
		return billType;
	}

	public void setBillType(String billType) {
		this.billType = billType;
	}

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public String getBillStateName() {
		return billStateName;
	}

	public void setBillStateName(String billStateName) {
		this.billStateName = billStateName;
	}

	public Long getProjectId() {
		return projectId;
	}

	@ReferDeserialTransfer
	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectCode() {
		return projectCode;
	}

	public void setProjectCode(String projectCode) {
		this.projectCode = projectCode;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getConstructionUnit() {
		return constructionUnit;
	}

	public void setConstructionUnit(String constructionUnit) {
		this.constructionUnit = constructionUnit;
	}

	public Date getRegistrationDeadline() {
		return registrationDeadline;
	}

	public void setRegistrationDeadline(Date registrationDeadline) {
		this.registrationDeadline = registrationDeadline;
	}

	public Date getBidOpenDate() {
		return bidOpenDate;
	}

	public void setBidOpenDate(Date bidOpenDate) {
		this.bidOpenDate = bidOpenDate;
	}

	public Long getBidUnitId() {
		return bidUnitId;
	}

	public void setBidUnitId(Long bidUnitId) {
		this.bidUnitId = bidUnitId;
	}

	public String getBidUnitCode() {
		return bidUnitCode;
	}

	public void setBidUnitCode(String bidUnitCode) {
		this.bidUnitCode = bidUnitCode;
	}

	public String getBidUnitName() {
		return bidUnitName;
	}

	public void setBidUnitName(String bidUnitName) {
		this.bidUnitName = bidUnitName;
	}

	public String getBidWinFlag() {
		return bidWinFlag;
	}

	public void setBidWinFlag(String bidWinFlag) {
		this.bidWinFlag = bidWinFlag;
	}

	public String getBidWinFlagName() {
		return bidWinFlagName;
	}

	public void setBidWinFlagName(String bidWinFlagName) {
		this.bidWinFlagName = bidWinFlagName;
	}

	public String getBidWinCompanyName() {
		return bidWinCompanyName;
	}

	public void setBidWinCompanyName(String bidWinCompanyName) {
		this.bidWinCompanyName = bidWinCompanyName;
	}

	public BigDecimal getBidWinMny() {
		return bidWinMny;
	}

	public void setBidWinMny(BigDecimal bidWinMny) {
		this.bidWinMny = bidWinMny;
	}

	public Date getHandleDate() {
		return handleDate;
	}

	public void setHandleDate(Date handleDate) {
		this.handleDate = handleDate;
	}

}
